<p align="center">
<img src="docs/_static/logo/medium.png">
</p>

[![Documentation Status](https://readthedocs.org/projects/ytopt/badge/?version=latest)](https://ytopt.readthedocs.io/en/latest/?badge=latest)

# What is Ytopt?

TODO

# Documentation

Ytopt documentation is on : [ReadTheDocs](https://ytopt.readthedocs.io)

# Directory structure

```
search/
    directory for search applications
```

# Install instructions

```
git clone https://github.com/ytopt-team/ytopt.git
cd ytopt/
pip install -e .
```
# How do I learn more?

* Documentation: https://ytopt.readthedocs.io

* GitHub repository: https://github.com/ytopt-team/ytopt

# Who is responsible?

The core Ytopt team is at Argonne National Laboratory:

TODO

# How can I participate?

TODO

# Acknowledgements

TODO

# Copyright and license

TBD